
import javafx.animation.Interpolator;
import javafx.animation.transition.AnimationPath;
import javafx.animation.transition.PathTransition;
import javafx.ext.swing.SwingButton;
import javafx.scene.Group;
import javafx.scene.Node;
import javafx.scene.Scene;
import javafx.scene.paint.Color;
import javafx.scene.paint.LinearGradient;
import javafx.scene.paint.Stop;
import javafx.scene.shape.SVGPath;
import javafx.stage.Stage;

import javafx.fxd.FXDContent;
import javafx.fxd.FXDLoader;

// Illustratorで作成したFXZファイルのロード
var content: FXDContent = FXDLoader.loadContent("{__DIR__}cherry.fxz");

// アニメーションのガイドパスに使用するためSVGPathにキャスト
var path: SVGPath = content.getShape("path") as SVGPath;
var peace = content.getNode("peace");
var cherry = content.getNode("cherry");

// アニメーションの状態を示す変数
var falling = false;

// ガイドパスに沿って移動するアニメーション
var animation = PathTransition {
    node: peace
    duration: 15s
    path: AnimationPath.createFromPath(path)
    interpolate: Interpolator.EASEBOTH

    // アニメーションが終わったときにコールされる関数
    action: function () {
        falling = false;
    }
}

Stage {
    title: "Cherry Blossom"
    scene: Scene {
        width: 200
        height: 300
        fill: LinearGradient {
            startX: 0.0 startY: 0.0
            endX: 0.0 endY: 1.0
            proportional: true
            stops: [
                Stop { offset: 0.0 color: Color.web("#6699FF") },
                Stop { offset: 1.0 color: Color.web("#DDDDFF") }
            ]
        }

        content: [
            SwingButton {
                translateX: 130
                translateY: 10
                text: bind if (falling) "Stop" else "Fall  "
                action: function() {
                    // アニメーション中にボタンがクリックされたらポーズ
                    // アニメーションが停止もしくはポーズのときにクリックされたらアニメーションを開始
                    if (falling) {
                        animation.pause();
                        falling = false;
                    } else {
                        animation.playFromStart();
                        falling = true;
                    }
                }
            },
            Group {
                translateX: 10
                translateY: 10
                content: [peace, cherry]
            }
        ]
    }
}